import { __awaiter } from 'tslib';
import { registerPlugin } from '@scullyio/scully';
import { createClient } from 'contentful';

// TODO: What to do about handling "HandledRoute" type?
const contentfulRoutePlugin = (route, conf) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const contentfulClientOptions = {
            space: conf.config.spaceId,
            accessToken: conf.config.accessToken
        };
        const client = createClient(contentfulClientOptions);
        const entries = yield client.getEntries({
            content_type: conf.config.contentType
        });
        return entries.map(e => (Object.assign({ route: `article/${e.sys.id}`, type: 'contentful' }, e.fields)));
    }
    catch (e) {
        let details;
        if (e.code === `ENOTFOUND`) {
            details = `You seem to be offline`;
        }
        else if (e.code === `SELF_SIGNED_CERT_IN_CHAIN`) {
            console.error(
            // tslint:disable-next-line:max-line-length
            `We couldn't make a secure connection to your contentful space. Please check if you have any self-signed SSL certificates installed.`);
        }
        else if (e.response) {
            if (e.response.status === 404) {
                // host and space used to generate url
                details = `Endpoint not found. Check if
          host
        and spaceId settings are correct`;
            }
            else if (e.response.status === 401) {
                // authorization error
                details = `Authorization error. Check if
          accessToken
        and environment are correct`;
            }
        }
        console.error(`Accessing your Contentful space failed.
    Try setting GATSBY_CONTENTFUL_OFFLINE=true to see if we can serve from cache.
    ${details ? `\n${details}\n` : ``}`);
    }
});
const validator = (conf) => __awaiter(void 0, void 0, void 0, function* () { return []; });
const ɵ0 = validator;
const Contentful = 'contentful';
registerPlugin('router', Contentful, contentfulRoutePlugin, validator);

/*
 * Public API Surface of scully-plugin-contentful
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Contentful };
//# sourceMappingURL=scully-plugin-contentful.js.map
